@@ -1,8 +1,10 @@
 from __future__ import annotations
 
+from functools import lru_cache
 from re import findall
 
 
+@lru_cache(maxsize=256)
 def to_camel(snake_string: str) -> str:
     """Converts a snake case string to camel case.
 
@@ -17,6 +19,7 @@ def to_camel(snake_string: str) -> str:
     return words[0] + "".join(word.title() for word in words[1:])
 
 
+@lru_cache(maxsize=256)
 def to_snake(camel_string: str) -> str:
     """Converts a camel case string to snake case.
 
@@ -31,6 +34,7 @@ def to_snake(camel_string: str) -> str:
     return "_".join(word.lower() for word in words)
 
 
+@lru_cache(maxsize=256)
 def to_upper_camel(snake_string: str) -> str:
     """Converts a snake case string to camel case.
 
